@@ -5,11 +5,11 @@
 #= Generate shell script "gt4config".
 #
 #   * Developers: Eizi TOYODA (toyoda), Yasuhiro MORIKAWA (morikawa)
-#   * Version: $Id: gt4configgen.sh,v 1.2 2005/09/04 12:19:54 morikawa Exp $
-#   * Tag Name: $Name: gt4f90io-20060618 $
+#   * Version: $Id: gt4configgen.sh,v 1.3 2006/06/19 05:19:40 morikawa Exp $
+#   * Tag Name: $Name: gt4f90io-20060619 $
 #   * Change History: 
 #
-fc="`which ${FC:?}`"
+fc="$FC"
 linker="$LINKF -I${MODINSTDIR:?}"
 fflags="-I${MODINSTDIR:?} $SYSFFLAGS"
 ldflags="$SYSLDFLAGS -L$LIBINSTDIR"
