@@ -5,12 +5,12 @@
 #= Generate shell script "gt4frt".
 #
 #   * Developers: Eizi TOYODA (toyoda), Yasuhiro MORIKAWA (morikawa)
-#   * Version: $Id: gt4frtgen.sh,v 1.3 2006/06/16 15:53:40 morikawa Exp $
-#   * Tag Name: $Name: gt4f90io-20060618 $
+#   * Version: $Id: gt4frtgen.sh,v 1.4 2006/06/19 05:19:40 morikawa Exp $
+#   * Tag Name: $Name: gt4f90io-20060619 $
 #   * Change History: 
 #
 
-fc="`which ${FC:?}`"
+fc="$FC"
 linker="$LINKF"
 mods="-I${MODINSTDIR:?}"
 fflags="${SYSFFLAGS}"
